@@ -322,13 +322,7 @@ class ImageXService(Service):
             raise Exception(res_json['ResponseMetadata'])
         return res_json['Result']
 
-    # action=0: refresh
-    # action=1: disable
-    # action=2: enable
     def update_image_urls(self, service_id, urls, action=0):
-        if action < 0 or action > 2:
-            raise Exception("update action should be [0,2], %d" % action)
-
         query = {
             'ServiceId': service_id
         }
@@ -371,6 +365,15 @@ class ImageXService(Service):
         res_json = json.loads(json.dumps(res))
         return res_json
 
+    def fetch_image_url(self, request):
+        res = self.imagex_post('FetchImageUrl', request, json.dumps(request))
+        if res == '':
+            raise Exception("empty response")
+        res_json = json.loads(res)
+        if 'Error' in res_json['ResponseMetadata']:
+            raise Exception(res_json['ResponseMetadata'])
+        return res_json['Result']
+
     def get_image_ocr(self, params):
         res = self.post('GetImageOCR', params, {})
         if res == '':
